<?php

if (!isset($gCms)) exit;


///// GLOBALS /////

$gCms = cmsms();
$smarty = &$gCms->GetSmarty();
$db = $gCms->GetDb();
$config = $gCms->GetConfig();
$tmp = $this->GetPreference('detail_returnid',-1);
$hm =& $gCms->GetHierarchyManager();
$page_meta = cms_utils::get_current_content();
$curalias = cms_utils::get_current_alias();
$curnode =& $hm->getNodeByAlias($curalias);
$curcontent =& $curnode->GetContent();
$modified_date = $curcontent->GetModifiedDate();
$modified_date = date('Y-m-d\TH:i:sP',$modified_date);
$currentYear = date('Y');

$countVars = '';
$countVars2 = '';
$canonical = '';
$pageMeta = '';
$meta_block = '';

if ($this->GetPreference('meta_block_title','') != '') {
    $meta_block = str_replace(' ','_',$this->GetPreference('meta_block_title',''));
} else {
    $meta_block_title = '';
}
if ($this->GetPreference('block_title','') != '') {
    $description_block = str_replace(' ','_',$this->GetPreference('block_title',''));
} else {
    $description_block = '';
}
if ($this->GetPreference('canonical_block_title','') != '') {
    $canonical_block = str_replace(' ','_',$this->GetPreference('canonical_block_title',''));
} else {
    $canonical_block = '';
}
if ($this->GetPreference('key_smarty','') != '') {
    $key_smarty = $this->GetPreference('key_smarty','');
} else {
    $key_smarty = '';
}
if ($this->GetPreference('html_title','en') != '') {
    $lang_block = $this->GetPreference('html_title','en');
} else {
    $lang_block = '';
}
if ($this->GetPreference('content_var_title','') != '') {
    $contentVar = $this->GetPreference('content_var_title','');
    $contentVar = str_replace(' ','', $contentVar);
    $contentVar = explode(',', $contentVar);
} else {
    $contentVar = '';
}


$pageSmarty = $this->GetPreference('page_smarty','');
$ogimageSmarty = $this->GetPreference('ogimage_smarty_title','');
$ogtypeSmarty = $this->GetPreference('ogtype_smarty_title','');


///// PAGE SPECIFIC METADATA /////

if (is_object($page_meta) && $page_meta->Metadata() != '' && $page_meta->Metadata() != '{* Add code here that should appear in the metadata section of all new pages *}') {
    $pageMeta = "\n" . $page_meta->Metadata();
}



///// KEYWORDS /////

$wordcount = $this->GetPreference('key_number','20');
$wordlength = $this->GetPreference('key_length','4');
$worddensity = $this->GetPreference('key_density','3');
$checkContent = $curcontent->GetPropertyValue('content_en');

if ($checkContent != '') {
    if ($contentVar != '') {
        foreach ($contentVar as $key => $countVar) {
            $countVars[] = $smarty->get_template_vars($countVar);
        }
        $countVars = join(' ', $countVars);
    }
    $contentBasic = $curcontent->GetPropertyValue('content_en');
    $keywords = $contentBasic . $countVars;
	$keywords = trim(preg_replace('/\t+/', '', $keywords));
    $keywords = preg_replace('/[\n\r]/','',$keywords);
    $keywords = preg_replace('/[\.\,]/','',$keywords);
    $keywords = str_replace('><','> <',$keywords);
    $keywords = strtolower($keywords);
    $keywords = strip_tags(str_replace('"','',$keywords));
    $keywords = preg_replace('/{.*}/','',$keywords);
    $keywords = preg_replace(array('/&[^\s]*;/'), '', $keywords);
    //$keywords = htmlentities($keywords, ENT_COMPAT, 'UTF-8'); //Commented out to solve unicode display problems
    //$keywords = utf8_encode(html_entity_decode($keywords)); //Commented out to solve unicode display problems
}

if ($keywords != '') {
    $keywords = explode(' ',$keywords);
} else {
    $keywords = '';
}
if ($keywords != '') {
    foreach ($keywords as $key => $word ) { //Turn Keywords into an array
        if (strlen($word) >= $wordlength) {
            $words[] = $word;
        }
    }

    $keywordsskip = $this->GetPreference('keyskip_title',''); //Get the list of STOP words
    $keywordsskip = str_replace(' ','',$keywordsskip);
    $keywordsskip = explode(',',$keywordsskip);

    foreach ($keywordsskip as $skipkey => $skipword ) { //Turn STOP words into an array
        $skipwords[] = $skipword;
    }

	if ($smarty->get_template_vars($key_smarty) != '') {
		$keywordssmarty = $smarty->get_template_vars($key_smarty);
		$keywordssmarty = str_replace(' ','',$keywordssmarty);
		$keywordssmarty = explode(',',$keywordssmarty);

    		foreach ($keywordssmarty as $smartkey => $smartword ) { //Turn Smarty keywords into an array
        		$smartwords[] = $smartword;
    		}
	}

    $keywordsdefault = $this->GetPreference('key_default',''); //Get the list of Default keywords to include
    $keywordsdefault = str_replace(' ','',$keywordsdefault);
    $keywordsdefault = explode(',',$keywordsdefault);

    foreach ($keywordsdefault as $defkey => $defword ) { //Turn Default keywords into an array
        $defwords[] = $defword;
    }
}

$keywordsskip = preg_split("/[\s,]+/", $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very, every, been, with, then, this, will, don\'t'));

if ($words != '') {
    $worddiff = array_diff($words, $skipwords); //Strip any STOP words out of the keywords
	if ($smarty->get_template_vars($key_smarty) != '') {
		$worddiff = array_diff($worddiff, $smartwords); //Strip any Smarty keywords out to prevent duplication
	}
	if ($this->GetPreference($key_smarty) != '') {
		$worddiff = array_diff($worddiff, $defwords); //Strip any Default keywords out to prevent duplication
	}
}

if (is_array($worddiff)) {
    $count = array_count_values($worddiff);
    array_multisort($count,SORT_DESC);
    $keycount = 0;
    $a = 1;
    $i = 1;
    $skipwords = '';
    $comma = ', ';
    foreach ($count as $keyCount => $valueCount) {
        if( $a <= $wordcount && $a != $keycount ) {
            if( $valueCount >= $worddensity) {
                $keycount++;
                $a++;
            }
        }
    }
    foreach ($count as $key => $value) {
        if( $i < $wordcount && $i != $keycount ) {
            if( $value >= $worddensity) {
                $skipwords .= ($key.$comma);
                $i++;
            }
        } elseif( $i == $wordcount || $i == $keycount ) {
            if( $value >= $worddensity) {
                $skipwords .= $key;
                $i++;
            }
        }
    }
} else {
    $skipwords = '';
}



///// DESCRIPTION /////

if ($this->GetPreference('block_title','') != '') {
	if ($smarty->get_template_vars($description_block) != '') {
	    $desc = $smarty->get_template_vars($description_block);
	    $desc = preg_replace('/[\n\r]/',' ',$desc);
	    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
	    $desc = str_replace('><','> <',$desc);
	    $desc = strip_tags(str_replace('"','',$desc));
	    $desc = preg_replace('/{.*}/','',$desc);
	    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
	} elseif ($curcontent->GetPropertyValue($description_block) != '') {
	    $desc = $curcontent->GetPropertyValue($description_block);
	    $desc = preg_replace('/[\n\r]/',' ',$desc);
	    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
	    $desc = str_replace('><','> <',$desc);
	    $desc = strip_tags(str_replace('"','',$desc));
	    $desc = preg_replace('/{.*}/','',$desc);
	    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
	} else {
		if ($contentVar != '') {
			foreach ($contentVar as $key => $countVar2) {
				$content_value = $smarty->get_template_vars($countVar2);
				if($content_value != "") {
					$countVars2[] = $content_value;
				}
				$content_value = NULL;
			}
			$countVars2 = preg_replace('!\s+!', ' ', trim(strip_tags(join(' ', $countVars2))));
		}
		$contentBasic = $curcontent->GetPropertyValue('content_en');
		$desc = $countVars2 . ' ' . $contentBasic;
		$desc = preg_replace('/[\n\r]/',' ',$desc);
		$desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
		$desc = str_replace('><','> <',$desc);
		$desc = strip_tags(str_replace('"','',$desc));
		$desc = preg_replace('/{.*}/','',$desc);
		$desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
		$desclength = $this->GetPreference('length_title','30');
		$desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
	}
} elseif ($this->GetPreference('auto_title','1') == '1') {
    if ($contentVar != '') {
        foreach ($contentVar as $key => $countVar2) {
			$content_value = $smarty->get_template_vars($countVar2);
			if($content_value != "") {
				$countVars2[] = $content_value;
			}
			$content_value = NULL;
        }
        $countVars2 = preg_replace('!\s+!', ' ', trim(strip_tags(join(' ', $countVars2))));
    }
    $contentBasic = $curcontent->GetPropertyValue('content_en');
    $desc = $countVars2 . ' ' . $contentBasic;
    $desc = preg_replace('/[\n\r]/',' ',$desc);
    $desc = preg_replace('/\s\s+/',' ',$desc); //Strip out whitespace
    $desc = str_replace('><','> <',$desc);
    $desc = strip_tags(str_replace('"','',$desc));
    $desc = preg_replace('/{.*}/','',$desc);
    $desc = preg_replace(array('/&[^\s]*;/'), '', $desc);
    $desclength = $this->GetPreference('length_title','30');
    $desc = preg_replace('/((\w+\W*){'.($desclength-1).'}(\w+))(.*)/', '${1}', $desc);
} else {
	$desc = '';
}


///// Canonical link /////

if ($curcontent->GetPropertyValue($canonical_block) != '') {
    $canonical = $curcontent->GetPropertyValue($canonical_block);
}


///// XML LANGUAGE /////
$xmlLang = $this->GetPreference('html_title','en');
$lang_count = '0';
if (preg_match('/{/', $xmlLang)) {
    $this->smarty->assign('html_title', $lang_block);
    $lang_block = str_replace('{$','',$lang_block);
    $lang_block = str_replace('}','',$lang_block);
    $lang_count = '1';
}



///// SET PREFERENCES /////

if ($this->GetPreference('allow_add',1) == 1) {
   $this->smarty->assign('currentYear', $currentYear);
   $this->smarty->assign('modified_date', $modified_date);
   $this->smarty->assign('base_title', $this->GetPreference('base_title','1'));
   $this->smarty->assign('baseslash_title', $this->GetPreference('baseslash_title','0'));
   $this->smarty->assign('base_url', $gCms->config['root_url']);
   $this->smarty->assign('site_name', get_site_preference('sitename'));
   $this->smarty->assign('page_title_current', $curcontent->name());
   $this->smarty->assign('page_smarty', $smarty->get_template_vars($pageSmarty));
   $this->smarty->assign('page_title', $this->GetPreference('page_title',''));
   $this->smarty->assign('delimiter_title', $this->GetPreference('delimiter_title','::'));
   $this->smarty->assign('meta_title', $this->GetPreference('meta_title',''));
   $this->smarty->assign('descriptions_title', $this->GetPreference('descriptions_title',''));
   $this->smarty->assign('keywordson_title', $this->GetPreference('keywordson_title','1'));
   $this->smarty->assign('keywords_title', $skipwords);
   $this->smarty->assign('keywords_default', $this->GetPreference('key_default',''));
   $this->smarty->assign('keywords_smarty', $smarty->get_template_vars($key_smarty));
   $this->smarty->assign('keyskip_title', $this->GetPreference('keyskip_title','i, me, my, myself, we, our, ours, ourselves, you, your, yours, yourself, yourselves, he, him, his, himself, she, her, hers, herself, it, its, itself, they, them, their, theirs, themselves, what, which, who, whom, this, that, these, those, am, is, are, was, were, be, been, being, have, has, had, having, do, does, did, doing, a, an, the, and, but, if, or, because, as, until, while, of, at, by, for, with, about, against, between, into, through, during, before, after, above, below, to, from, up, down, in, out, on, off, over, under, again, further, then, once, here, there, when, where, why, how, all, any, both, each, few, more, most, other, some, such, no, nor, not, only, own, same, so, than, too, very, every, been, with, then, this, will, don\'t'));
   $this->smarty->assign('standard_title', $this->GetPreference('standard_title','1'));
   $this->smarty->assign('dublin_title', $this->GetPreference('dublin_title','0'));
   $this->smarty->assign('opengraph_title', $this->GetPreference('opengraph_title','0'));
   $this->smarty->assign('tweetme_title', $this->GetPreference('tweetme_title','0'));
   $this->smarty->assign('touchicon_root_title', $this->GetPreference('touchicon_root_title','0'));
   $this->smarty->assign('touchicon_title', $this->GetPreference('touchicon_title','0'));
   $this->smarty->assign('fullscreen_title', $this->GetPreference('fullscreen_title','-1'));
   $this->smarty->assign('statusbar_title', $this->GetPreference('statusbar_title','-1'));
   $this->smarty->assign('phoneno_title', $this->GetPreference('phoneno_title','-1'));
   $this->smarty->assign('width_title', $this->GetPreference('width_title',''));
   $this->smarty->assign('height_title', $this->GetPreference('height_title',''));
   $this->smarty->assign('initial_title', $this->GetPreference('initial_title',''));
   $this->smarty->assign('minimum_title', $this->GetPreference('minimum_title',''));
   $this->smarty->assign('maximum_title', $this->GetPreference('maximum_title',''));
   $this->smarty->assign('scalable_title', $this->GetPreference('scalable_title','-1'));
   $this->smarty->assign('robots_title', $this->GetPreference('robots_title','-1'));
   $this->smarty->assign('publisher_title', $this->GetPreference('publisher_title',''));
   $this->smarty->assign('contributor_title', $this->GetPreference('contributor_title',''));
   $this->smarty->assign('relation_title', $this->GetPreference('relation_title',''));
   $this->smarty->assign('email_title', $this->GetPreference('email_title',''));
   $this->smarty->assign('phone_title', $this->GetPreference('phone_title',''));
   $this->smarty->assign('fax_title', $this->GetPreference('fax_title',''));
   $this->smarty->assign('street_title', $this->GetPreference('street_title',''));
   $this->smarty->assign('location_title', $this->GetPreference('location_title',''));
   $this->smarty->assign('region_title', $this->GetPreference('region_title',''));
   $this->smarty->assign('postcode_title', $this->GetPreference('postcode_title',''));
   $this->smarty->assign('country_title', $this->GetPreference('country_title',''));
   $this->smarty->assign('latitude_title', $this->GetPreference('latitude_title',''));
   $this->smarty->assign('longitude_title', $this->GetPreference('longitude_title',''));
   $this->smarty->assign('ogtype_title', $this->GetPreference('ogtype_title',''));
   $this->smarty->assign('ogtype_smarty_title', $smarty->get_template_vars($ogtypeSmarty));
   $this->smarty->assign('ogimage_title', $this->GetPreference('ogimage_title','0'));
   $this->smarty->assign('ogimage_smarty_title', $smarty->get_template_vars($ogimageSmarty));
   $this->smarty->assign('favicon_root_title', $this->GetPreference('favicon_root_title','0'));
   $this->smarty->assign('favicon_title', $this->GetPreference('favicon_title','0'));
   $this->smarty->assign('favsize_title', $this->GetPreference('favsize_title',''));
   $this->smarty->assign('fbpage_title', $this->GetPreference('fbpage_title',''));
   $this->smarty->assign('fbadmin_title', $this->GetPreference('fbadmin_title',''));
   $this->smarty->assign('fbapp_title', $this->GetPreference('fbapp_title',''));
   $this->smarty->assign('twittersite_title', $this->GetPreference('twittersite_title',''));
   $this->smarty->assign('googleplus_title', $this->GetPreference('googleplus_title',''));
   $this->smarty->assign('analyticstype_title', $this->GetPreference('analyticstype_title','-1'));
   $this->smarty->assign('analytics_support', $this->GetPreference('analytics_support','0'));
   $this->smarty->assign('analytics_enhanced_link', $this->GetPreference('analytics_enhanced_link','0'));
   $this->smarty->assign('propertyid_title', $this->GetPreference('propertyid_title',''));
   $this->smarty->assign('webmasterid_title', $this->GetPreference('webmasterid_title',''));
   $this->smarty->assign('pretty_title', $this->GetPreference('pretty_title','0'));
   $this->smarty->assign('post_title', $this->GetPreference('post_title','0'));
   $this->smarty->assign('query_title', $this->GetPreference('query_title',''));
   $this->smarty->assign('results_title', $this->GetPreference('results_title',''));
   $this->smarty->assign('bingid_title', $this->GetPreference('bingid_title',''));
   $this->smarty->assign('opendoctype_title', $this->GetPreference('opendoctype_title','0'));
   $this->smarty->assign('doctype_title', $this->GetPreference('doctype_title','-1'));
   $this->smarty->assign('xmlns_title', $this->GetPreference('xmlns_title','0'));
   $this->smarty->assign('dir_title', $this->GetPreference('dir_title','0'));
   $this->smarty->assign('dirchoice_title', $this->GetPreference('dirchoice_title','-1'));
   $this->smarty->assign('lang_title', $this->GetPreference('lang_title','0'));
   if ($lang_count != '0') {
       $this->smarty->assign('html_title', $smarty->get_template_vars($lang_block));
   }else{
       $this->smarty->assign('html_title', $this->GetPreference('html_title','en'));
   }
   $this->smarty->assign('xmllang_title', $this->GetPreference('xmllang_title','0'));
   $this->smarty->assign('htmlextra_title', $this->GetPreference('htmlextra_title',''));
   $this->smarty->assign('openhtml_title', $this->GetPreference('openhtml_title','0'));
   $this->smarty->assign('openhead_title', $this->GetPreference('openhead_title','0'));
   $this->smarty->assign('closehead_title', $this->GetPreference('closehead_title','0'));
   $this->smarty->assign('additional_title', $this->GetPreference('additional_title',''));
   $this->smarty->assign('stylesheet_title', $this->GetPreference('stylesheet_title','0'));
   $this->smarty->assign('stylesheet_name', $this->GetPreference('stylesheet_name','0'));
   $this->smarty->assign('stylesheet_nocombine', $this->GetPreference('stylesheet_nocombine','0'));
   $this->smarty->assign('stylesheet_nolinks', $this->GetPreference('stylesheet_nolinks','0'));
   $this->smarty->assign('stylesheet_https', $this->GetPreference('stylesheet_https','0'));
   $this->smarty->assign('stylesheet_templateid', $this->GetPreference('stylesheet_templateid','0'));
   $this->smarty->assign('stylesheet_media', $this->GetPreference('stylesheet_media','0'));
   $this->smarty->assign('jquery_title', $this->GetPreference('jquery_title','0'));
   $this->smarty->assign('jquery_exclude', $this->GetPreference('jquery_exclude',''));
   $this->smarty->assign('jquery_include', $this->GetPreference('jquery_include',''));
   $this->smarty->assign('jquery_cnd', $this->GetPreference('jquery_cnd','false'));
   $this->smarty->assign('jquery_ssl', $this->GetPreference('jquery_ssl','0'));
   $this->smarty->assign('jquery_custom_root', $this->GetPreference('jquery_custom_root',''));
   $this->smarty->assign('jquery_assign', $this->GetPreference('jquery_assign',''));
   $this->smarty->assign('compatible_title', $this->GetPreference('compatible_title','0'));
   $this->smarty->assign('compatibleie_title', $this->GetPreference('compatibleie_title','-1'));
   $this->smarty->assign('compatiblechrome_title', $this->GetPreference('compatiblechrome_title','-1'));
   $this->smarty->assign('meta_block', $curcontent->GetPropertyValue($meta_block));
   $this->smarty->assign('description_block', $curcontent->GetPropertyValue($description_block));
   $this->smarty->assign('page_description', $desc);
   $this->smarty->assign('canonical', $canonical);
   $this->smarty->assign('contentText', $countVars);
   $this->smarty->assign('pageMeta', $pageMeta);
}



///// DISPLAY MODULE MESSAGES /////

if (isset($params['module_message'])) {
   $this->smarty->assign('module_message',$params['module_message']);
} else {
   $this->smarty->assign('module_message','');
}

///// PROCESS AND DISPLAY TEMPLATE /////

echo $this->ProcessTemplate('metamax.tpl');

?>